<p align="center">
  <a href="https://github.com/pydykit/pydykit"><img alt="pydykit" src="https://raw.githubusercontent.com/pydykit/pydykit/main/docs/assets/banner.png" width="50%"></a>
</p>

[![Pytest](https://github.com/pydykit/pydykit/actions/workflows/pytest.yml/badge.svg)](https://github.com/pydykit/pydykit/actions/workflows/pytest.yml)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)
[![PyPI](https://img.shields.io/pypi/v/pydykit)](https://pypi.org/project/pydykit)
<!-- [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pydykit)](https://pypi.org/project/pydykit) -->

# `pydykit`: A *Py*thon-based *dy*namics simulation tool*kit*

`pydykit` provides a basic framework for the simulation of dynamical systems.
The package is based on time stepping methods,
which are discrete versions of the corresponding dynamics equations - either ordinary differential equations (ODEs) or differential-algebraic equations (DAEs).

## Getting Started

Follow detailed steps in the
[documentation][pydykit_docs]
or shortcut with

```bash
pip install pydykit
```

## Contributing

Please refer to [CONTRIBUTIONG.md](CONTRIBUTING.md).
Feel free to contact us if you have doubts or questions.

## Main Contributors

- **Julian K. Bauer** - _Code architect_ - [@JulianKarlBauer](https://github.com/JulianKarlBauer)
- **Philipp L. Kinon** - _Core developer_ - [@plkinon](https://github.com/plkinon)

See also the list of [contributors](https://github.com/pydykit/pydykit/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

[pydykit_docs]: https://pydykit.github.io/pydykit/
